class AandeelData:
    def __init__(self, markt=None, ticker=None, prijs=None, aantal=None):
        """
        Initialize the AandeelData object.

        Args:
            markt (str): The market name OR the aandeelData string (default: None).
            ticker (str): The ticker symbol (default: None).
            prijs (float): The price (default: None).
            aantal (int): The quantity (default: None).
        """
        if markt is not None and ticker is not None and prijs is not None and aantal is not None:
            self.markt = markt
            self.ticker = ticker
            self.prijs = prijs
            self.aantal = aantal
        else:
            # Parse the aandeelData string if provided
            if markt is not None:
                self._parse_aandeel_data(markt)

    def _parse_aandeel_data(self, aandeel_data):
        """
        Parse the aandeelData string and set the object's attributes.

        Args:
            aandeel_data (str): The string representing aandeelData.
        """
        line_array = aandeel_data.split(";")
        self.markt = line_array[0]
        self.ticker = line_array[1]
        self.prijs = float(line_array[2])
        self.aantal = int(line_array[3])

    def get_markt(self):
        """
        Get the market of the stock.
        Returns:
            The market of the stock.
        """
        return self.markt

    def get_ticker(self):
        """
        Get the ticker symbol of the stock.
        Returns:
            The ticker symbol of the stock.
        """
        return self.ticker

    def get_prijs(self):
        """
        Get the price of the stock.
        Returns:
            The price of the stock.
        """
        return self.prijs

    def set_prijs(self, prijs):
        """
        Set the price of the stock.
        Args:
            prijs: The new price of the stock.
        """
        self.prijs = prijs

    def get_aantal(self):
        """
        Get the quantity of the stock.
        Returns:
            The quantity of the stock.
        """
        return self.aantal

    @staticmethod
    def create_key(markt, ticker):
        """
        Create a key for the stock using the market and ticker symbol.
        Args:
            markt: The market of the stock.
            ticker: The ticker symbol of the stock.
        Returns:
            The key for the stock.
        """
        return markt + "-" + ticker
