import os
from aandeel_data import AandeelData

class FileReader:
    def __init__(self, filename="portefeuille.txt"):
        """
        Initialize the FileReader object.
        
        Args:
            filename (str): The name of the log file.
        """
        self.entries = []
        self.data_iterator = None
        try:
            # Get the absolute path of the file.
            file_path = os.path.join(os.path.dirname(__file__), filename)
            with open(file_path, "r") as file:
                for line in file:
                    aandeel_data = line.strip()
                    entry = AandeelData(aandeel_data)
                    self.entries.append(entry)
            self.reset()
        except FileNotFoundError:
            print("File not found: " + filename)

    def has_next(self):
        """
        Check if the reader has more stock data to supply.
        
        Returns:
            bool: True if there is more data available, False otherwise.
        """
        return self.data_iterator is not None and self.data_iterator.has_next()

    def next(self):
        """
        Get the next stock data.
        
        Returns:
            AandeelData: The next AandeelData object containing the data.
        """
        return self.data_iterator.next()

    def remove(self):
        """
        Remove an entry.
        This operation is not permitted.
        """
        print("It is not permitted to remove entries.")

    def reset(self):
        """
        Set up a fresh iterator to provide access to the data.
        This allows a single file of data to be processed more than once.
        """
        self.data_iterator = iter(self.entries)

    def print_data(self):
        """
        Print the stock data.
        """
        for entry in self.entries:
            print(
                entry.get_markt(),
                entry.get_ticker(),
                entry.get_prijs(),
                entry.get_aantal()
            )
